@@ -1,7 +1,3 @@
-import os
-from pathlib import Path
-
-
 def pull(data, path, value):
     if len(path) == 0:
         return False, data
@@ -45,7 +41,3 @@ def put(data, path, value):
 
     data[path[0]] = {}
     return put(data[path[0]], path[1:], value)
-
-
-def get_storage_path(name):
-    return os.getenv('HOME') / Path(f".{name}.yaml")
